import React, { useEffect, useState } from 'react';
import * as datav from '@jiaminghi/data-view-react';
import styles from './sliderData.less';
import { connect } from '@@/plugin-dva/exports';
import { JSONPath } from 'jsonpath-plus';

interface propsData {
  data: any;
  MQTTMessage: any;
}

/**
 * 底部轮播
 * @constructor
 */
const SliderData: React.FC<propsData> = (props) => {
  const { data, MQTTMessage } = props;
  const [voltage, setVoltage] = useState({ ua: 0 });
  const [current, setCurrent] = useState({ ia: 0 });
  const [activePower, setActivePower] = useState({ active_power: 0 });
  const [controlData, setControlData] = useState({
    power: data.power ? data.power : 0,
    mode: data.mode,
    set_temp: data.set_temp,
    temperature: data.temperature,
    humidity: data.humidity,
    air_quality: data.air_quality,
    co2: data.co2,
  });

  useEffect(() => {
    // 电
    if (
      MQTTMessage.message?.DeviceCode === 'DT645-4G' &&
      MQTTMessage.message?.SubDeviceId !== '' &&
      data.electric_id !== '' &&
      MQTTMessage.message?.SubDeviceId === data.electric_id
    ) {
      // 电压
      if (Object.keys(MQTTMessage.message.Data)[0] === 'voltage') {
        setVoltage({ ua: JSONPath({ json: MQTTMessage.message.Data, path: '$.voltage.ua' })[0] });
      }
      // 电流
      if (Object.keys(MQTTMessage.message.Data)[0] === 'current') {
        setCurrent({ ia: JSONPath({ json: MQTTMessage.message.Data, path: '$.current.ia' })[0] });
      }
      // 用电量
      if (Object.keys(MQTTMessage.message.Data)[0] === 'power') {
        setActivePower({
          active_power: JSONPath({
            json: MQTTMessage.message.Data,
            path: '$.power.active_power',
          })[0],
        });
      }
    }

    //温湿度等
    if (
      MQTTMessage.message?.DeviceCode === data.device_id &&
      MQTTMessage.message?.SubDeviceId === ''
    ) {
      setControlData({
        power: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.power' })[0],
        mode: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.mode' })[0],
        set_temp: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.set_temp' })[0],
        temperature: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.temperature' })[0],
        humidity: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.humidity' })[0],
        air_quality: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.air_quality' })[0],
        co2: JSONPath({ json: MQTTMessage.message.Data, path: '$.status.co2' })[0],
      });
    }
  }, [MQTTMessage.message?.DeviceCode && MQTTMessage.message?.SubDeviceId]);

  const handleCo2Grade = (co2: number) => {
    if (co2 >= 0 && co2 < 800) {
      return '#90c456';
    }
    if (co2 >= 800 && co2 < 1600) {
      return '#eceb3b';
    }
    if (co2 >= 1600) {
      return '#e4151b';
    }
    return '';
  };

  const handlePm25Grade = (pm25: number) => {
    if (pm25 >= 0 && pm25 <= 50) {
      return '#90c456';
    }
    if (pm25 > 50 && pm25 < 150) {
      return '#eceb3b';
    }
    if (pm25 >= 150) {
      return '#e4151b';
    }
    return '';
  };

  // const chartRef: any = useRef();
  //
  // const colorSet = {
  //   color: '#0063E7'
  // }
  // const dataArr = 70;

  // useEffect(() => {
  // const myChart = echarts.init(chartRef.current);
  // const options = {
  //   series: [
  //     {
  //       name: "内部进度条",
  //       type: "gauge",
  //       radius: '50%',
  //       axisLine: {
  //         show: false
  //         // lineStyle: {
  //         //   color: [
  //         //     [1, colorSet.color]
  //         //   ],
  //         //   width: 3,
  //         //   shadowColor: 'rgba(145,207,255,.5)',
  //         //   shadowBlur: 6,
  //         //   shadowOffsetX: 0,
  //         // }
  //       },
  //       axisLabel: {
  //         show: false,
  //       },
  //       axisTick: {
  //         show: false,
  //       },
  //       splitLine: {
  //         show: false,
  //       },
  //       itemStyle: {
  //         show: false,
  //       },
  //       detail: {
  //         formatter: function(value: number) {
  //           if (value !== 0) {
  //             const num = Math.round(value ) ;
  //             return parseInt(String(num)).toFixed(0);
  //           } else {
  //             return 0;
  //           }
  //         },
  //         offsetCenter: [0, 30],
  //         textStyle: {
  //           padding: [0, 0, 0, 0],
  //           fontSize: 18,
  //           fontWeight: '700',
  //           color: colorSet.color
  //         }
  //       },
  //       title: { //标题
  //         show: true,
  //         offsetCenter: [0, 70], // x, y，单位px
  //         textStyle: {
  //           color: "#fff",
  //           fontSize: 14, //表盘上的标题文字大小
  //           fontWeight: 400,
  //           fontFamily: 'PingFangSC'
  //         }
  //       },
  //       data: [{
  //         name: "电压",
  //         value: dataArr,
  //       }],
  //       pointer: {
  //         show: true,
  //         length: '75%',
  //         radius: '20%',
  //         width: 5, //指针粗细
  //       },
  //       animationDuration: 4000,
  //     },
  //     {
  //       name: '外部刻度',
  //       type: 'gauge',
  //       radius: '80%',
  //       min: 0, //最小刻度
  //       max: 230, //最大刻度
  //       startAngle: 225,
  //       endAngle: -45,
  //       axisLine: {
  //         show: true,
  //         lineStyle: {
  //           width: 1,
  //           color: [
  //             [1, 'rgba(0,0,0,0)']
  //           ]
  //         }
  //       }, //仪表盘轴线
  //       axisLabel: {
  //         show: true,
  //         color: '#4d5bd1',
  //         distance: 25,
  //       },
  //       //刻度标签。
  //       axisTick: {
  //         show: true,
  //         splitNumber: 7,
  //         lineStyle: {
  //           color: colorSet.color, //用颜色渐变函数不起作用
  //           width: 1,
  //         },
  //         length: -8
  //       }, //刻度样式
  //       splitLine: {
  //         show: true,
  //         length: -20,
  //         lineStyle: {
  //           color: colorSet.color, //用颜色渐变函数不起作用
  //         }
  //       }, //分隔线样式
  //       detail: {
  //         show: false
  //       },
  //       pointer: {
  //         show: false
  //       }
  //     },
  //   ]
  // }
  // myChart.setOption(options, true);
  // // 组件卸载
  // return () => {
  //   myChart.dispose();
  // };
  // }, []);

  //  四舍五入保留一位小数
  // const decimal = (num: number) => {
  //   return Math.round(num * 10) / 10;
  // };

  return (
    <div>
      <datav.BorderBox12
        className={styles.decoration_bottom_border}
        style={{ width: '30vw', height: '26vh' }}
      >
        <div className={styles.home_detail}>
          <div className={styles.detail_left}>
            <div className={styles.detail_left_left}>
              <div className={styles.decoration_on} />
              <div className={styles.home_name}>{data?.home_name ? data?.home_name : '我的家'}</div>
            </div>
            <div className={styles.detail_left_right}>
              <table className={styles.detail_item}>
                <tbody>
                  <tr>
                    <td className={styles.detail_item_title}>管理员</td>
                    <td className={styles.detail_item_value}>{data?.admin}</td>
                  </tr>
                  <tr>
                    <td className={styles.detail_item_title}>是否在线</td>
                    <td
                      className={styles.detail_item_value}
                      style={{ color: `${data?.is_online ? '#90c456' : '#e4151b'}` }}
                    >
                      {data?.is_online ? '在线' : '离线'}
                    </td>
                  </tr>
                  <tr>
                    <td className={styles.detail_item_title}>运行状态</td>
                    <td className={styles.detail_item_value} style={{ color: '#ffb026' }}>
                      {{ 0: '关', 1: '开' }[controlData.power]}
                    </td>
                  </tr>
                  <tr>
                    <td className={styles.detail_item_title}>模式</td>
                    <td className={styles.detail_item_value}>
                      {{ 0: '制冷', 1: '制热', 2: '除湿', 3: '送风', 4: '加湿' }[controlData?.mode]}
                    </td>
                  </tr>
                </tbody>
              </table>
            </div>
          </div>
          <div className={styles.detail_right}>
            <div className={styles.detail_right_top}>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>设定温度</div>
                <div className={styles.content_value}>{controlData?.set_temp}°C</div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>室内温度</div>
                <div className={styles.content_value}>{controlData?.temperature}°C</div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>湿度</div>
                <div className={styles.content_value}>{controlData?.humidity}%rh</div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>PM25</div>
                <div
                  className={styles.content_value}
                  style={{ color: handlePm25Grade(controlData?.air_quality) }}
                >
                  {controlData?.air_quality}μg/m³
                </div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>CO2</div>
                <div
                  className={styles.content_value}
                  style={{ color: handleCo2Grade(controlData?.co2) }}
                >
                  {controlData?.co2}
                </div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>用电量</div>
                <div className={styles.content_value}>{activePower?.active_power}kwh</div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>电压</div>
                <div className={styles.content_value}>{voltage?.ua}V</div>
              </div>
              <div className={styles.detail_right_top_content}>
                <div className={styles.content_title}>电流</div>
                <div className={styles.content_value}>{current?.ia}A</div>
              </div>
            </div>
            {/*<div style={{ color: '#fff', marginTop: '10px' }}>用电量</div>*/}
            {/*<div className={styles.detail_right_bottom}>*/}
            {/*  <div ref={chartRef} style={{ width: '11vw', height: '17vh' , marginTop:'8px' }} />*/}
            {/*  <div className={styles.electric_content}>*/}
            {/*    <div className={styles.content_num}><span>总电量：</span><span>122</span></div>*/}
            {/*    <div className={styles.content_num}><span>电压：</span><span>122</span></div>*/}
            {/*  </div>*/}
            {/*</div>*/}
          </div>
        </div>
      </datav.BorderBox12>
    </div>
  );
};
export default connect(({ MQTTMessage }: any) => ({
  MQTTMessage,
}))(SliderData);
